@@ -53,6 +53,7 @@ MainWindow::MainWindow(
     coverClosesApp(false),
     useCameraButton(false),
     useOffTimer(false),
+    flashAfterTimeout(false),
     ui(new Ui::MainWindow)
 {
   ui->setupUi(this);
@@ -392,6 +393,13 @@ void MainWindow::setOffTimerDuration(
 }
 
 
+void MainWindow::setFlashAfterTimeout(
+  bool flag)
+{
+  flashAfterTimeout = flag;
+}
+
+
 void MainWindow::strobe()
 {
   // Do nothing if camera cover is closed:
@@ -416,7 +424,7 @@ void MainWindow::updateCameraCover(
 
     turnTorchOff();
 
-    // If "coverClosesApp" has been set, exit Linguine immediately:
+    // If "coverClosesApp" has been set, exit Lanterne immediately:
     if (coverClosesApp)
     {
       QApplication::quit();
@@ -671,6 +679,21 @@ void MainWindow::torchTimeout()
   }
 
   offTimer.stop();
+
+  if (flashAfterTimeout)
+  {
+    // Start flashing the low-power LED, to help find the phone now that the
+    // torch is off.
+    ui->whiteButton->setChecked(false);
+    ui->redButton->setChecked(true);
+    useIndicatorLED(true);
+    if (!morseForm)
+    {
+      morseForm = new LanMorseForm(this);
+    }
+    morseForm->startE();
+    loopRunning = true;
+  }
 }
 
 
